@@ -7,7 +7,7 @@
   and Eclipse Distribution License v1.0 which accompany this distribution.
 
   The Eclipse Public License is available at
-     http://www.eclipse.org/legal/epl-v10.html
+     http://www.eclipse.org/legal/epl-v20.html
   and the Eclipse Distribution License is available at
     http://www.eclipse.org/org/documents/edl-v10.php.
 
@@ -16,19 +16,18 @@
 *******************************************************************
 """
 
-import getopt
 import logging
 import sys
 import threading
 import time
-import traceback
 import unittest
+import unittest.mock
 
 import paho.mqtt
 import paho.mqtt.client
+from paho.mqtt.enums import CallbackAPIVersion
 from paho.mqtt.packettypes import PacketTypes
 from paho.mqtt.properties import Properties
-from paho.mqtt.reasoncodes import ReasonCodes
 from paho.mqtt.subscribeoptions import SubscribeOptions
 
 
@@ -118,14 +117,17 @@ class Callbacks:
 
 def cleanRetained(port):
     callback = Callbacks()
-    curclient = paho.mqtt.client.Client("clean retained".encode("utf-8"),
-                                        protocol=paho.mqtt.client.MQTTv5)
+    curclient = paho.mqtt.client.Client(
+        CallbackAPIVersion.VERSION1,
+        b"clean retained",
+        protocol=paho.mqtt.client.MQTTv5,
+    )
     curclient.loop_start()
     callback.register(curclient)
     curclient.connect(host="localhost", port=port)
-    response = callback.wait_connected()
+    callback.wait_connected()
     curclient.subscribe("#", options=SubscribeOptions(qos=0))
-    response = callback.wait_subscribed()  # wait for retained messages to arrive
+    callback.wait_subscribed()  # wait for retained messages to arrive
     time.sleep(1)
     for message in callback.messages:
         logging.info("deleting retained message for topic", message["message"])
@@ -141,8 +143,11 @@ def cleanup(port):
     clientids = ("aclient", "bclient")
 
     for clientid in clientids:
-        curclient = paho.mqtt.client.Client(clientid.encode(
-            "utf-8"), protocol=paho.mqtt.client.MQTTv5)
+        curclient = paho.mqtt.client.Client(
+            CallbackAPIVersion.VERSION1,
+            clientid.encode("utf-8"),
+            protocol=paho.mqtt.client.MQTTv5,
+        )
         curclient.loop_start()
         curclient.connect(host="localhost", port=port, clean_start=True)
         time.sleep(.1)
@@ -164,21 +169,25 @@ class Test(unittest.TestCase):
         sys.path.append("paho.mqtt.testing/interoperability/")
         try:
             import mqtt.brokers
-        except ImportError:
-            raise unittest.SkipTest("paho.mqtt.testing not present.")
+        except ImportError as ie:
+            raise unittest.SkipTest("paho.mqtt.testing not present.") from ie
 
-        cls._test_broker = threading.Thread(
-            target=mqtt.brokers.run,
-            kwargs={
-                "config": ["listener 0"],
-            },
-        )
-        cls._test_broker.daemon = True
-        cls._test_broker.start()
-        # Wait a bit for TCP server to bind to an address
-        time.sleep(0.5)
-        # Hack to find the port used by the test broker...
-        cls._test_broker_port = mqtt.brokers.listeners.TCPListeners.server.socket.getsockname()[1]
+        # Hack: we need to patch `signal.signal()` because `mqtt.brokers.run()`
+        #       calls it to set up a signal handler; however, that won't work
+        #       from a thread...
+        with unittest.mock.patch("signal.signal", unittest.mock.MagicMock()):
+            cls._test_broker = threading.Thread(
+                target=mqtt.brokers.run,
+                kwargs={
+                    "config": ["listener 0"],
+                },
+            )
+            cls._test_broker.daemon = True
+            cls._test_broker.start()
+            # Wait a bit for TCP server to bind to an address
+            time.sleep(0.5)
+            # Hack to find the port used by the test broker...
+            cls._test_broker_port = mqtt.brokers.listeners.TCPListeners.server.socket.getsockname()[1]
         setData()
         cleanup(cls._test_broker_port)
 
@@ -187,12 +196,10 @@ class Test(unittest.TestCase):
 
         #aclient = mqtt_client.Client(b"\xEF\xBB\xBF" + "myclientid".encode("utf-8"))
         #aclient = mqtt_client.Client("myclientid".encode("utf-8"))
-        aclient = paho.mqtt.client.Client("aclient".encode(
-            "utf-8"), protocol=paho.mqtt.client.MQTTv5)
+        aclient = paho.mqtt.client.Client(CallbackAPIVersion.VERSION1, b"aclient", protocol=paho.mqtt.client.MQTTv5)
         callback.register(aclient)
 
-        bclient = paho.mqtt.client.Client("bclient".encode(
-            "utf-8"), protocol=paho.mqtt.client.MQTTv5)
+        bclient = paho.mqtt.client.Client(CallbackAPIVersion.VERSION1, b"bclient", protocol=paho.mqtt.client.MQTTv5)
         callback2.register(bclient)
 
     @classmethod
@@ -244,10 +251,6 @@ class Test(unittest.TestCase):
         fclient.loop_stop()
 
     def test_retained_message(self):
-        qos0topic = "fromb/qos 0"
-        qos1topic = "fromb/qos 1"
-        qos2topic = "fromb/qos2"
-        wildcardtopic = "fromb/+"
 
         publish_properties = Properties(PacketTypes.PUBLISH)
         publish_properties.UserProperty = ("a", "2")
@@ -328,7 +331,7 @@ class Test(unittest.TestCase):
 
         callback0 = Callbacks()
 
-        client0 = paho.mqtt.client.Client(protocol=paho.mqtt.client.MQTTv5)
+        client0 = paho.mqtt.client.Client(CallbackAPIVersion.VERSION1, protocol=paho.mqtt.client.MQTTv5)
         callback0.register(client0)
         client0.loop_start()
         # should not be rejected
@@ -340,7 +343,7 @@ class Test(unittest.TestCase):
         client0.disconnect()
         client0.loop_stop()
 
-        client0 = paho.mqtt.client.Client(protocol=paho.mqtt.client.MQTTv5)
+        client0 = paho.mqtt.client.Client(CallbackAPIVersion.VERSION1, protocol=paho.mqtt.client.MQTTv5)
         callback0.register(client0)
         client0.loop_start()
         client0.connect(host="localhost", port=self._test_broker_port)  # should work
@@ -353,7 +356,8 @@ class Test(unittest.TestCase):
 
         # when we supply a client id, we should not get one assigned
         client0 = paho.mqtt.client.Client(
-            "client0", protocol=paho.mqtt.client.MQTTv5)
+            CallbackAPIVersion.VERSION1, "client0", protocol=paho.mqtt.client.MQTTv5,
+        )
         callback0.register(client0)
         client0.loop_start()
         client0.connect(host="localhost", port=self._test_broker_port)  # should work
@@ -368,24 +372,25 @@ class Test(unittest.TestCase):
         # message queueing for offline clients
         cleanRetained(self._test_broker_port)
         ocallback = Callbacks()
-        clientid = "offline message queueing".encode("utf-8")
+        clientid = b"offline message queueing"
 
         oclient = paho.mqtt.client.Client(
-            clientid, protocol=paho.mqtt.client.MQTTv5)
+            CallbackAPIVersion.VERSION1, clientid, protocol=paho.mqtt.client.MQTTv5,
+        )
         ocallback.register(oclient)
         connect_properties = Properties(PacketTypes.CONNECT)
         connect_properties.SessionExpiryInterval = 99999
         oclient.loop_start()
         oclient.connect(host="localhost", port=self._test_broker_port, properties=connect_properties)
-        response = ocallback.wait_connected()
+        ocallback.wait_connected()
         oclient.subscribe(wildtopics[5], qos=2)
-        response = ocallback.wait_subscribed()
+        ocallback.wait_subscribed()
         oclient.disconnect()
         oclient.loop_stop()
 
         bclient.loop_start()
         bclient.connect(host="localhost", port=self._test_broker_port)
-        response = callback2.wait_connected()
+        callback2.wait_connected()
         bclient.publish(topics[1], b"qos 0", 0)
         bclient.publish(topics[2], b"qos 1", 1)
         bclient.publish(topics[3], b"qos 2", 2)
@@ -394,11 +399,12 @@ class Test(unittest.TestCase):
         bclient.loop_stop()
 
         oclient = paho.mqtt.client.Client(
-            clientid, protocol=paho.mqtt.client.MQTTv5)
+            CallbackAPIVersion.VERSION1, clientid, protocol=paho.mqtt.client.MQTTv5,
+        )
         ocallback.register(oclient)
         oclient.loop_start()
         oclient.connect(host="localhost", port=self._test_broker_port, clean_start=False)
-        response = ocallback.wait_connected()
+        ocallback.wait_connected()
         time.sleep(2)
         oclient.disconnect()
         oclient.loop_stop()
@@ -413,10 +419,11 @@ class Test(unittest.TestCase):
         # the server may send back one message with the highest QoS of any matching subscription, or one message for
         # each subscription with a matching QoS.
         ocallback = Callbacks()
-        clientid = "overlapping subscriptions".encode("utf-8")
+        clientid = b"overlapping subscriptions"
 
         oclient = paho.mqtt.client.Client(
-            clientid, protocol=paho.mqtt.client.MQTTv5)
+            CallbackAPIVersion.VERSION1, clientid, protocol=paho.mqtt.client.MQTTv5,
+        )
         ocallback.register(oclient)
 
         oclient.loop_start()
@@ -444,14 +451,15 @@ class Test(unittest.TestCase):
         ocallback.clear()
 
     def test_subscribe_failure(self):
-        # Subscribe failure.  A new feature of MQTT 3.1.1 is the ability to send back negative reponses to subscribe
+        # Subscribe failure.  A new feature of MQTT 3.1.1 is the ability to send back negative responses to subscribe
         # requests.  One way of doing this is to subscribe to a topic which is not allowed to be subscribed to.
         logging.info("Subscribe failure test starting")
 
         ocallback = Callbacks()
-        clientid = "subscribe failure".encode("utf-8")
+        clientid = b"subscribe failure"
         oclient = paho.mqtt.client.Client(
-            clientid, protocol=paho.mqtt.client.MQTTv5)
+            CallbackAPIVersion.VERSION1, clientid, protocol=paho.mqtt.client.MQTTv5,
+        )
         ocallback.register(oclient)
         oclient.loop_start()
         oclient.connect(host="localhost", port=self._test_broker_port)
@@ -460,7 +468,7 @@ class Test(unittest.TestCase):
         response = ocallback.wait_subscribed()
 
         self.assertEqual(response["reasonCodes"][0].getName(), "Unspecified error",
-                         "return code should be 0x80 %s" % response["reasonCodes"][0].getName())
+                         f"return code should be 0x80 {response['reasonCodes'][0].getName()}")
         oclient.disconnect()
         oclient.loop_stop()
 
@@ -479,7 +487,7 @@ class Test(unittest.TestCase):
         # Unsubscribe from one topic
         bclient.unsubscribe(topics[0])
         callback2.wait_unsubscribed()
-        callback2.clear()  # if there were any retained messsages
+        callback2.clear()  # if there were any retained messages
 
         aclient.connect(host="localhost", port=self._test_broker_port)
         aclient.loop_start()
@@ -497,8 +505,11 @@ class Test(unittest.TestCase):
 
     def new_client(self, clientid):
         callback = Callbacks()
-        client = paho.mqtt.client.Client(clientid.encode(
-            "utf-8"), protocol=paho.mqtt.client.MQTTv5)
+        client = paho.mqtt.client.Client(
+            CallbackAPIVersion.VERSION1,
+            clientid.encode("utf-8"),
+            protocol=paho.mqtt.client.MQTTv5,
+        )
         callback.register(client)
         client.loop_start()
         return client, callback
@@ -658,10 +669,10 @@ class Test(unittest.TestCase):
         pclient, pcallback = self.new_client(clientid)
         pclient.loop_start()
         pclient.connect_async(host="localhost", port=self._test_broker_port)
-        response = pcallback.wait_connected()
+        pcallback.wait_connected()
 
         pclient.subscribe(topics[0], qos=2)
-        response = pcallback.wait_subscribed()
+        pcallback.wait_subscribed()
         publish_properties = Properties(PacketTypes.PUBLISH)
         publish_properties.PayloadFormatIndicator = 1
         publish_properties.ContentType = "My name"
@@ -705,19 +716,19 @@ class Test(unittest.TestCase):
         connect_properties = Properties(PacketTypes.CONNECT)
         connect_properties.SessionExpiryInterval = 99999
 
-        lbclient, lbcallback = self.new_client(clientid+" b")
+        lbclient, lbcallback = self.new_client(f"{clientid} b")
         lbclient.loop_start()
         lbclient.connect(host="localhost", port=self._test_broker_port, properties=connect_properties)
-        response = lbcallback.wait_connected()
+        lbcallback.wait_connected()
         lbclient.subscribe(topics[0], qos=2)
-        response = lbcallback.wait_subscribed()
+        lbcallback.wait_subscribed()
         disconnect_properties = Properties(PacketTypes.DISCONNECT)
         disconnect_properties.SessionExpiryInterval = 999999999
         lbclient.disconnect(properties=disconnect_properties)
         lbcallback.wait_disconnected()
         lbclient.loop_stop()
 
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.loop_start()
         laclient.connect(host="localhost", port=self._test_broker_port)
         publish_properties = Properties(PacketTypes.PUBLISH)
@@ -735,7 +746,7 @@ class Test(unittest.TestCase):
                          2, retain=False, properties=publish_properties)
 
         time.sleep(3)
-        lbclient, lbcallback = self.new_client(clientid+" b")
+        lbclient, lbcallback = self.new_client(f"{clientid} b")
         lbclient.loop_start()
         lbclient.connect(host="localhost", port=self._test_broker_port, clean_start=False)
         lbcallback.wait_connected()
@@ -758,7 +769,7 @@ class Test(unittest.TestCase):
         # noLocal
         clientid = 'subscribe options - noLocal'
 
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port)
         lacallback.wait_connected()
         laclient.loop_start()
@@ -766,7 +777,7 @@ class Test(unittest.TestCase):
             topics[0], options=SubscribeOptions(qos=2, noLocal=True))
         lacallback.wait_subscribed()
 
-        lbclient, lbcallback = self.new_client(clientid+" b")
+        lbclient, lbcallback = self.new_client(f"{clientid} b")
         lbclient.connect(host="localhost", port=self._test_broker_port)
         lbcallback.wait_connected()
         lbclient.loop_start()
@@ -789,7 +800,7 @@ class Test(unittest.TestCase):
 
         # retainAsPublished
         clientid = 'subscribe options - retain as published'
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port)
         lacallback.wait_connected()
         laclient.subscribe(topics[0], options=SubscribeOptions(
@@ -813,7 +824,7 @@ class Test(unittest.TestCase):
 
         # retainHandling
         clientid = 'subscribe options - retain handling'
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port)
         lacallback.wait_connected()
         laclient.publish(topics[1], b"qos 0", 0, retain=True)
@@ -840,7 +851,7 @@ class Test(unittest.TestCase):
         properties.UserProperty = ("a", "2")
         properties.UserProperty = ("c", "3")
         laclient.unsubscribe(wildtopics[5], properties)
-        response = lacallback.wait_unsubscribed()
+        lacallback.wait_unsubscribed()
 
         # check that we really did remove that subscription
         laclient.subscribe(
@@ -861,7 +872,7 @@ class Test(unittest.TestCase):
         properties.UserProperty = ("a", "2")
         properties.UserProperty = ("c", "3")
         laclient.unsubscribe(wildtopics[5], properties)
-        response = lacallback.wait_unsubscribed()
+        lacallback.wait_unsubscribed()
 
         lacallback.clear()
         laclient.subscribe(
@@ -875,7 +886,7 @@ class Test(unittest.TestCase):
 
         # remove that subscription
         laclient.unsubscribe(wildtopics[5])
-        response = lacallback.wait_unsubscribed()
+        lacallback.wait_unsubscribed()
 
         laclient.subscribe(
             wildtopics[5], options=SubscribeOptions(2, retainHandling=0))
@@ -899,7 +910,7 @@ class Test(unittest.TestCase):
     def test_subscription_identifiers(self):
         clientid = 'subscription identifiers'
 
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port)
         lacallback.wait_connected()
         laclient.loop_start()
@@ -909,7 +920,7 @@ class Test(unittest.TestCase):
         laclient.subscribe(topics[0], qos=2, properties=sub_properties)
         lacallback.wait_subscribed()
 
-        lbclient, lbcallback = self.new_client(clientid+" b")
+        lbclient, lbcallback = self.new_client(f"{clientid} b")
         lbclient.connect(host="localhost", port=self._test_broker_port)
         lbcallback.wait_connected()
         lbclient.loop_start()
@@ -920,7 +931,7 @@ class Test(unittest.TestCase):
 
         sub_properties.clear()
         sub_properties.SubscriptionIdentifier = 3
-        lbclient.subscribe(topics[0]+"/#", qos=2, properties=sub_properties)
+        lbclient.subscribe(f"{topics[0]}/#", qos=2, properties=sub_properties)
 
         lbclient.publish(topics[0], b"sub identifier test", 1, retain=False)
 
@@ -934,7 +945,7 @@ class Test(unittest.TestCase):
 
         self.waitfor(lbcallback.messages, 1, 3)
         self.assertEqual(len(lbcallback.messages), 1, lbcallback.messages)
-        expected_subsids = set([2, 3])
+        expected_subsids = {2, 3}
         received_subsids = set(
             lbcallback.messages[0]["message"].properties.SubscriptionIdentifier)
         self.assertEqual(received_subsids, expected_subsids, received_subsids)
@@ -945,12 +956,12 @@ class Test(unittest.TestCase):
     def test_request_response(self):
         clientid = 'request response'
 
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port)
         lacallback.wait_connected()
         laclient.loop_start()
 
-        lbclient, lbcallback = self.new_client(clientid+" b")
+        lbclient, lbcallback = self.new_client(f"{clientid} b")
         lbclient.connect(host="localhost", port=self._test_broker_port)
         lbcallback.wait_connected()
         lbclient.loop_start()
@@ -995,25 +1006,10 @@ class Test(unittest.TestCase):
     def test_client_topic_alias(self):
         clientid = 'client topic alias'
 
-        # no server side topic aliases allowed
-        laclient, lacallback = self.new_client(clientid+" a")
-        laclient.connect(host="localhost", port=self._test_broker_port)
-        connack = lacallback.wait_connected()
-        laclient.loop_start()
-
-        publish_properties = Properties(PacketTypes.PUBLISH)
-        publish_properties.TopicAlias = 0  # topic alias 0 not allowed
-        laclient.publish(topics[0], "topic alias 0", 1,
-                         properties=publish_properties)
-
-        # should get back a disconnect with Topic alias invalid
-        lacallback.wait_disconnected()
-        laclient.loop_stop()
-
         connect_properties = Properties(PacketTypes.CONNECT)
         connect_properties.TopicAliasMaximum = 0  # server topic aliases not allowed
         connect_properties.SessionExpiryInterval = 99999
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port, properties=connect_properties)
         connack = lacallback.wait_connected()
         clientTopicAliasMaximum = 0
@@ -1046,7 +1042,7 @@ class Test(unittest.TestCase):
         laclient.loop_stop()
 
         # check aliases have been deleted
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port, clean_start=False,
                          properties=connect_properties)
 
@@ -1070,13 +1066,10 @@ class Test(unittest.TestCase):
         connect_properties = Properties(PacketTypes.CONNECT)
         connect_properties.TopicAliasMaximum = serverTopicAliasMaximum
 
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port, properties=connect_properties)
-        connack = lacallback.wait_connected()
+        lacallback.wait_connected()
         laclient.loop_start()
-        clientTopicAliasMaximum = 0
-        if hasattr(connack["properties"], "TopicAliasMaximum"):
-            clientTopicAliasMaximum = connack["properties"].TopicAliasMaximum
 
         laclient.subscribe(topics[0], qos=2)
         lacallback.wait_subscribed()
@@ -1109,15 +1102,11 @@ class Test(unittest.TestCase):
         connect_properties = Properties(PacketTypes.CONNECT)
         # connect_properties.TopicAliasMaximum = serverTopicAliasMaximum # default is 0
 
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port, properties=connect_properties)
-        connack = lacallback.wait_connected()
+        lacallback.wait_connected()
         laclient.loop_start()
 
-        clientTopicAliasMaximum = 0
-        if hasattr(connack["properties"], "TopicAliasMaximum"):
-            clientTopicAliasMaximum = connack["properties"].TopicAliasMaximum
-
         laclient.subscribe(topics[0], qos=2)
         lacallback.wait_subscribed()
 
@@ -1141,15 +1130,11 @@ class Test(unittest.TestCase):
         connect_properties = Properties(PacketTypes.CONNECT)
         connect_properties.TopicAliasMaximum = serverTopicAliasMaximum  # default is 0
 
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port, properties=connect_properties)
-        connack = lacallback.wait_connected()
+        lacallback.wait_connected()
         laclient.loop_start()
 
-        clientTopicAliasMaximum = 0
-        if hasattr(connack["properties"], "TopicAliasMaximum"):
-            clientTopicAliasMaximum = connack["properties"].TopicAliasMaximum
-
         laclient.subscribe(topics[0], qos=2)
         lacallback.wait_subscribed()
 
@@ -1173,7 +1158,7 @@ class Test(unittest.TestCase):
         clientid = 'maximum packet size'
 
         # 1. server max packet size
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port)
         connack = lacallback.wait_connected()
         laclient.loop_start()
@@ -1202,7 +1187,7 @@ class Test(unittest.TestCase):
         connect_properties = Properties(PacketTypes.CONNECT)
         connect_properties.MaximumPacketSize = maximumPacketSize
 
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port, properties=connect_properties)
         connack = lacallback.wait_connected()
         laclient.loop_start()
@@ -1260,7 +1245,7 @@ class Test(unittest.TestCase):
         will_properties.WillDelayInterval = 3  # in seconds
         connect_properties.SessionExpiryInterval = 5
 
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.will_set(
             topics[0], payload=b"test_will_delay will message", properties=will_properties)
         laclient.connect(host="localhost", port=self._test_broker_port, properties=connect_properties)
@@ -1269,7 +1254,7 @@ class Test(unittest.TestCase):
         self.assertEqual(connack["flags"]["session present"], False)
         laclient.loop_start()
 
-        lbclient, lbcallback = self.new_client(clientid+" b")
+        lbclient, lbcallback = self.new_client(f"{clientid} b")
         lbclient.connect(host="localhost", port=self._test_broker_port, properties=connect_properties)
         connack = lbcallback.wait_connected()
         lbclient.loop_start()
@@ -1296,10 +1281,10 @@ class Test(unittest.TestCase):
     def test_shared_subscriptions(self):
         clientid = 'shared subscriptions'
 
-        shared_sub_topic = '$share/sharename/' + topic_prefix + 'x'
-        shared_pub_topic = topic_prefix + 'x'
+        shared_sub_topic = f"$share/sharename/{topic_prefix}x"
+        shared_pub_topic = f"{topic_prefix}x"
 
-        laclient, lacallback = self.new_client(clientid+" a")
+        laclient, lacallback = self.new_client(f"{clientid} a")
         laclient.connect(host="localhost", port=self._test_broker_port)
         connack = lacallback.wait_connected()
         laclient.loop_start()
@@ -1309,9 +1294,9 @@ class Test(unittest.TestCase):
 
         laclient.subscribe(
             [(shared_sub_topic, SubscribeOptions(2)), (topics[0], SubscribeOptions(2))])
-        response = lacallback.wait_subscribed()
+        lacallback.wait_subscribed()
 
-        lbclient, lbcallback = self.new_client(clientid+" b")
+        lbclient, lbcallback = self.new_client(f"{clientid} b")
         lbclient.connect(host="localhost", port=self._test_broker_port)
         connack = lbcallback.wait_connected()
         lbclient.loop_start()
@@ -1321,14 +1306,14 @@ class Test(unittest.TestCase):
 
         lbclient.subscribe(
             [(shared_sub_topic, SubscribeOptions(2)), (topics[0], 2)])
-        response = lbcallback.wait_subscribed()
+        lbcallback.wait_subscribed()
 
         lacallback.clear()
         lbcallback.clear()
 
         count = 1
         for i in range(count):
-            lbclient.publish(topics[0], "message "+str(i), 0)
+            lbclient.publish(topics[0], f"message {i}", 0)
         j = 0
         while len(lacallback.messages) + len(lbcallback.messages) < 2*count and j < 20:
             time.sleep(.1)
@@ -1341,7 +1326,7 @@ class Test(unittest.TestCase):
         lbcallback.clear()
 
         for i in range(count):
-            lbclient.publish(shared_pub_topic, "message "+str(i), 0)
+            lbclient.publish(shared_pub_topic, f"message {i}", 0)
         j = 0
         while len(lacallback.messages) + len(lbcallback.messages) < count and j < 20:
             time.sleep(.1)
