@@ -1,9 +1,11 @@
 import contextlib
 import socket
+import socketserver
 import threading
 
 import pytest
-from six.moves import socketserver
+
+from tests import paho_test
 
 
 class FakeBroker:
@@ -12,8 +14,9 @@ class FakeBroker:
         # http://docs.python.org/howto/sockets.html#ipc
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-        sock.settimeout(30)
-        sock.bind(("localhost", 1888))
+        sock.settimeout(5)
+        sock.bind(("localhost", 0))
+        self.port = sock.getsockname()[1]
         sock.listen(1)
 
         self._sock = sock
@@ -24,7 +27,7 @@ class FakeBroker:
             raise ValueError('Socket is not open')
 
         (conn, address) = self._sock.accept()
-        conn.settimeout(10)
+        conn.settimeout(5)
         self._conn = conn
 
     def finish(self):
@@ -50,6 +53,12 @@ class FakeBroker:
         count = self._conn.send(packet_out)
         return count
 
+    def expect_packet(self, name, packet):
+        if self._conn is None:
+            raise ValueError('Connection is not open')
+
+        paho_test.expect_packet(self._conn, name, packet)
+
 
 @pytest.fixture
 def fake_broker():
@@ -68,10 +77,10 @@ class ThreadedTCPServer(socketserver.ThreadingMixIn, socketserver.TCPServer):
 
 class FakeWebsocketBroker(threading.Thread):
     def __init__(self):
-        super(FakeWebsocketBroker, self).__init__()
+        super().__init__()
 
         self.host = "localhost"
-        self.port = 1888
+        self.port = -1  # Will be set by `serve()`
 
         self._server = None
         self._running = True
@@ -79,10 +88,11 @@ class FakeWebsocketBroker(threading.Thread):
 
     @contextlib.contextmanager
     def serve(self, tcphandler):
-        self._server = ThreadedTCPServer((self.host, self.port), tcphandler)
+        self._server = ThreadedTCPServer((self.host, 0), tcphandler)
 
         try:
             self.start()
+            self.port = self._server.server_address[1]
 
             if not self._running:
                 raise RuntimeError("Error starting server")
@@ -99,8 +109,6 @@ class FakeWebsocketBroker(threading.Thread):
 
 @pytest.fixture
 def fake_websocket_broker():
-    socketserver.TCPServer.allow_reuse_address = True
-
     broker = FakeWebsocketBroker()
 
     yield broker
